@@ -17,6 +17,7 @@ import subprocess
 import sys
 import traceback
 
+from six import PY2
 from six import text_type
 
 import monasca_agent.collector.checks as checks
@@ -101,6 +102,7 @@ class MySql(checks.AgentCheck):
         # Metric collection
         self._collect_metrics(host, db, dimensions, options)
         self._collect_system_metrics(host, db, dimensions)
+        db.close()
 
     @staticmethod
     def _get_config(instance):
@@ -371,7 +373,10 @@ class MySql(checks.AgentCheck):
                                            'pid'],
                                           stdout=subprocess.PIPE,
                                           close_fds=True).communicate()[0]
-                    pslines = ps.strip().split('\n')
+                    if PY2:
+                        pslines = ps.strip().split('\n')
+                    else:
+                        pslines = ps.decode('utf-8').strip().split('\n')
                     # First line is header, second line is mysql pid
                     if len(pslines) == 2 and pslines[1] != '':
                         pid = int(pslines[1])
